LoggingMiddleware class final

Logs navigation transitions.

Implemented types

Constructors

LoggingMiddleware({void onLog(String message) = _defaultLog})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
onLog → void Function(String message)
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onAfter(MiddlewareContext context, NavigationResult result) → void
override
onBefore(MiddlewareContext context) → void
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited