MiddlewareContext class final
Context for middleware hooks.
Constructors
- MiddlewareContext({required NavigationState previousState, required NavigationState targetState, Object? extra})
-
const
Properties
- extra → Object?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- previousState → NavigationState
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- targetState → NavigationState
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited